/**
 * Beispielsprogramm zur Demonstration des Abspeicherns ber oracle.sdoapi.geom.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */

import static gdbutil.ConnectionParameters.*;

import java.sql.*;

import oracle.sql.STRUCT;
import oracle.sdoapi.OraSpatialManager;
import oracle.sdoapi.adapter.GeometryAdapter;
import oracle.sdoapi.adapter.GeometryOutputTypeNotSupportedException;
import oracle.sdoapi.geom.*;
import oracle.sdoapi.sref.SpatialReference;
import oracle.sdoapi.sref.SRException;
import oracle.sdoapi.sref.SRManager;

public class SdoapiStoreExample {

public static void main (String[] args) {
	try {
		// Verbindung zur Datenbank aufbauen
		Class.forName("oracle.jdbc.driver.OracleDriver");
		String url = "jdbc:oracle:thin:@" + DBHOST + ":" + DBPORT + ":" + DBNAME;  // JDBC Thin Driver
			// bei JDBC OCI Driver:  "jdbc:oracle:oci:@" + DBSERVICENAME;
		Connection db = DriverManager.getConnection(url, DBUSER, DBPASSWORD);

		// GeometryAdapter holen
		GeometryAdapter adapter = OraSpatialManager.getGeometryAdapter
			("SDO","8.1.6",STRUCT.class,STRUCT.class,null,db);
		if (adapter == null) {
			db.close();
			throw new ClassNotFoundException("Kein GeometryAdapter!");
		}

		// Koordinatensystem holen
		SRManager srm = OraSpatialManager.getSpatialReferenceManager(db);
		SpatialReference cs = srm.retrieve(4326);
		if (cs == null) {
			db.close();
			throw new ClassNotFoundException("Keine SpatialReference!");
		}
		// GeometryFactory holen
		GeometryFactory gf = OraSpatialManager.getGeometryFactory(cs);
		
		// Insert vorbereiten
		String sql = "INSERT INTO Gemeinden (gkz,name,einw,centrum,gebiet) VALUES (1056025,'Helgoland',1499,?,?)";
		PreparedStatement insert = db.prepareStatement(sql);
		// Punkt setzen
		Point centrum = gf.createPoint(7.936,54.204);
		Object obj = adapter.exportGeometry(STRUCT.class,centrum);
		insert.setObject (1,obj);
		// Gebiet setzen
		double coords[] = {7.923,54.210, 7.944,54.194, 7.952,54.197, 7.945,54.209, 7.938,54.211, 7.923,54.210};
		LineString ring = gf.createLineString(coords);
		Polygon gebiet = gf.createPolygon(ring,null);	// null, da kein Lcher
		obj = adapter.exportGeometry(STRUCT.class,gebiet);
		insert.setObject (2,obj);
		// Einfgen
		insert.executeUpdate();
		insert.close();

		// Verbindung schlieen
		db.close();
	} // try

	// Fehlerbehandlung, falls die Klasse nicht gefunden wird
	catch (ClassNotFoundException ex) {
		System.err.println("SdoapiStoreExample.main: "+ex);
	}
	// Fehlerbehandlung beim Datenbankzugriff
	catch (SQLException ex) {
		System.err.println("SdoapiStoreExample.main: "+ex);
	}
	// Fehlerbehandlung bei der Umwandlung
	catch (GeometryOutputTypeNotSupportedException ex) {
		System.err.println("SdoapiStoreExample.main: "+ex);
	}
	catch (InvalidGeometryException ex) {
		System.err.println("SdoapiStoreExample.main: "+ex);
	}
	// Fehlerbehandlung fr Koordinatensystem
	catch (SRException ex) {
		System.err.println("SdoapiStoreExample.main: "+ex);
	}
}
}
