/**
 * Beispielsprogramm zur Demonstration der API oracle.spatial.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */

import static gdbutil.ConnectionParameters.*;

import java.io.*;
import java.sql.*;

import oracle.sql.STRUCT;
import oracle.spatial.util.GeometryExceptionWithContext;
import oracle.spatial.util.WKT;

public class SpatialWktExample {

public static void main (String[] args) {
	try {
		// Verbindung zur Datenbank aufbauen
		Class.forName("oracle.jdbc.driver.OracleDriver");
		String url = "jdbc:oracle:thin:@" + DBHOST + ":" + DBPORT + ":" + DBNAME;  // JDBC Thin Driver
			// bei JDBC OCI Driver:  "jdbc:oracle:oci:@" + DBSERVICENAME;
		Connection db = DriverManager.getConnection(url, DBUSER, DBPASSWORD);

		// Anfrage ausfhren
		Statement statement = db.createStatement();
		String sql = "SELECT * FROM Gemeinden WHERE gkz = 3403000";
		ResultSet result = statement.executeQuery(sql);
		WKT wkt = new WKT();
		if (result.next()) {
			// Attribut "centrum"
			STRUCT struct = (STRUCT) result.getObject("centrum");
			byte[] wktPoint = wkt.fromSTRUCT(struct);
			String wktString = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(wktPoint))).readLine();
			System.out.println(wktString);
			System.out.println();
			// Attribut "gebiet"
			struct = (STRUCT) result.getObject("gebiet");
			byte[] wktPolygon = wkt.fromSTRUCT(struct);
			wktString = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(wktPolygon))).readLine();
			System.out.println(wktString);
		}
		result.close();
		statement.close();
	
		// Verbindung schlieen
		db.close();
	} // try

	// Fehlerbehandlung, falls die Klasse nicht gefunden wird:
	catch (ClassNotFoundException ex) {
		System.err.println("SpatialWktExample.main: "+ex);
	}
	// Fehlerbehandlung beim Datenbankzugriff:
	catch (SQLException ex) {
		System.err.println("SpatialWktExample.main: "+ex);
	}
	// Fehlerbehandlung beim WKT-Erzeugung:
	catch (GeometryExceptionWithContext ex) {
		System.err.println("SpatialWktExample.main: "+ex);
	}
	// Fehlerbehandlung IO:
	catch (IOException ex) {
		System.err.println("SpatialWktExample.main: "+ex);
	}
}
}
